@@ -72,6 +72,13 @@ class RequestHandlerComponent extends Component {
  */
 	public $ext = null;
 
+/**
+ * Array of parameters parsed from the URL.
+ *
+ * @var array|null
+ */
+	public $params = null;
+
 /**
  * The template to use when rendering the given content type.
  *
@@ -132,7 +139,7 @@ class RequestHandlerComponent extends Component {
 		if (empty($this->ext) || $this->ext === 'html') {
 			$this->_setExtension();
 		}
-		$this->params = $controller->params;
+		$this->params = $controller->request->params;
 		if (!empty($this->settings['viewClassMap'])) {
 			$this->viewClassMap($this->settings['viewClassMap']);
 		}
@@ -213,7 +220,7 @@ class RequestHandlerComponent extends Component {
 
 		foreach ($this->_inputTypeMap as $type => $handler) {
 			if ($this->requestedWith($type)) {
-				$input = call_user_func_array(array($controller->request, 'input'), $handler);
+				$input = (array)call_user_func_array(array($controller->request, 'input'), $handler);
 				$controller->request->data = $input;
 			}
 		}
@@ -264,8 +271,10 @@ class RequestHandlerComponent extends Component {
 		}
 		if (!empty($status)) {
 			$statusCode = $this->response->httpCodes($status);
-			$code = key($statusCode);
-			$this->response->statusCode($code);
+			if (is_array($statusCode)) {
+				$code = key($statusCode);
+				$this->response->statusCode($code);
+			}
 		}
 		$this->response->body($this->requestAction($url, array('return', 'bare' => false)));
 		$this->response->send();
